# Copyright (c) 2000-2012, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%bcond_without repolib

%define reltag _redhat_1
%define namedreltag -redhat-1
%global namedversion %{version}%{?namedreltag}

Name:           h2database
Version:        1.3.161
Release:        0.3%{?reltag}%{?dist}
Epoch:          0
Summary:        Java SQL database
Group:          Development/Libraries
License:        MPL/EPL
URL:            http://www.h2database.com/html/main.html
%if 0
svn -q export -r 4033 http://h2database.googlecode.com/svn/tags/version-1.3.161/h2 h2-1.3.161 && tar cjf h2-1.3.161.tar.bz2 h2-1.3.161
%endif
Source0:        h2-1.3.161.tar.bz2
Patch0:         h2database-pom-versions.patch
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:       jpackage-utils
%if 0
Requires:       lucene
Requires:       org.osgi.core
Requires:       servlet_api
Requires:       slf4j
%endif
BuildRequires:  java-devel
BuildRequires:  jboss-parent
BuildRequires:  jpackage-utils
BuildRequires:  org.osgi.core
BuildRequires:  lucene
%if %with repolib
BuildRequires:  maven2-plugin-deploy
%endif
BuildRequires:  servlet_api
BuildRequires:  slf4j >= 0:1.6.1
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Welcome to H2, the Java SQL database. The main features of 
H2 are:
* Very fast, open source, JDBC API
* Embedded and server modes; in-memory databases
* Browser based Console application
* Small footprint: around 1 MB jar file size 

%package javadoc
Summary:        Javadoc for h2
Group:          Documentation
Requires:       jpackage-utils

%description javadoc
%{summary}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n h2-%{version}
# FIXME: patch backup breaks build (javadoc)
%patch0 -p1

# XXX: allows easy servlet upgrade
%{__rm} src/test/org/h2/test/unit/TestServlet.java

%{_bindir}/find -type f -name "*.exe" | %{_bindir}/xargs -t %{__rm}
%{_bindir}/find -type f -name "*.dll" | %{_bindir}/xargs -t %{__rm}
%{_bindir}/find -type f -name "*.jar" | %{_bindir}/xargs -t %{__rm}

%{__mkdir} ext
pushd ext
%{__ln_s} `%{_bindir}/build-classpath servlet_api` servlet-api-2.4.jar
%{__ln_s} `%{_bindir}/build-classpath lucene` lucene-core-2.2.0.jar
%{__ln_s} `%{_bindir}/build-classpath slf4j/slf4j-api` slf4j-api-1.5.0.jar
%{__ln_s} `%{_bindir}/build-classpath org.osgi.core` org.osgi.core-1.2.0.jar
popd

%{__perl} -p -e 's|\@version\@|%{namedversion}|g;' src/installer/pom-template.xml > h2-%{namedversion}.pom

%build
export CLASSPATH=
export JAVA_HOME=%{java_home}
./build.sh jar javadoc

%install
%{__rm} -rf %{buildroot}

# jar
%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p bin/h2-%{version}.jar %{buildroot}%{_javadir}/h2-%{namedversion}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{namedversion}*; do %{__ln_s} ${jar} ${jar/-%{namedversion}/}; done)

# pom
%{__mkdir_p} %{buildroot}%{_mavenpomdir}
%{__cp} -p h2-%{namedversion}.pom %{buildroot}%{_mavenpomdir}/JPP-h2.pom
%add_to_maven_depmap com.h2database h2 %{namedversion} JPP h2
if [ "%{name}" != "h2" ]; then
    %{__mv} %{buildroot}%{_mavendepmapfragdir}/%{name} %{buildroot}%{_mavendepmapfragdir}/h2
fi

%{__mkdir_p} %{buildroot}%{_javadocdir}/h2-%{namedversion}
%{__cp} -pr docs/javadoc/* %{buildroot}%{_javadocdir}/h2-%{namedversion}
%{__ln_s} h2-%{namedversion} %{buildroot}%{_javadocdir}/h2

%if %with repolib
%{_bindir}/mvn-jpp -Dmaven.repo.local=`pwd`/.m2/repository deploy:deploy-file -Dversion=%{namedversion} -Dfile=%{buildroot}%{_javadir}/h2-%{namedversion}.jar -DpomFile=%{buildroot}%{_mavenpomdir}/JPP-h2.pom -Durl=file://%{buildroot}%{_javadir}/repository.jboss.com/maven2-brew -DrepositoryId=oss-releases
%endif

%clean
%{__rm} -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%{_javadir}*/h2-%{namedversion}.jar
%{_javadir}*/h2.jar
%{_mavenpomdir}/JPP-h2.pom
%{_mavendepmapfragdir}/h2

%files javadoc
%defattr(644,root,root,755)
%{_javadocdir}/h2-%{namedversion}
%{_javadocdir}/h2

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}*
%exclude %dir %{_javadocdir}
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Tue Apr 17 2012 David Walluck <dwalluck@redhat.com> 0:1.3.161-0.3
- update pom
- remove .dll files
- remove .exe files

* Mon Mar 26 2012 Fernando Nasser <fnasser@redhat.com> - 0:1.3.161-0.2_redhat_1.1
- Rebuild using cache signing

* Fri Dec 02 2011 David Walluck <dwalluck@redhat.com> 0:1.3.161-0.2
- remove optional Requires (that are not in POM)
- add release tag to from POM to RPM Release tag

* Fri Dec 02 2011 David Walluck <dwalluck@redhat.com> 0:1.3.161-0.1
- 1.3.161

* Tue Nov 29 2011 David Walluck <dwalluck@redhat.com> 0:1.2.147-0.1
- 1.2.147
- use h2 name
- remove buildmagic repolib from this branch

* Mon Sep 12 2011 David Walluck <dwalluck@redhat.com> 0:1.2.145-2.2
- add pom patch

* Mon Sep 12 2011 David Walluck <dwalluck@redhat.com> 0:1.2.145-2.1
- use org.osgi.core, not felix
- fix servlet-api symlink
- fix slf4j symlink
- fix ant call
- fix 'mvn deploy:deploy-file call and args
- exclude javadoc dir from repolib files
- switch back to standard repolib location
- fail if ant would have tried to go online to get jars

* Fri Nov 12 2010 David Walluck <dwalluck@redhat.com> 0:1.2.145-2
- add maven repo
- fix repolib

* Fri Nov 12 2010 David Walluck <dwalluck@redhat.com> 0:1.2.145-1
- 1.2.145
- install bundled pom
- use servlet_2_5_api

* Fri Sep 24 2010 Ralph Apel <r.apel@r-apel.de> 1.1.119-1
- First release
